@@ -4,9 +4,9 @@
 (*                                                                     *)
 (*               Pierre Weis, projet Cristal, INRIA Rocquencourt       *)
 (*                                                                     *)
-(*  Copyright 2000 Institut National de Recherche en Informatique et   *)
+(*  Copyright 2001 Institut National de Recherche en Informatique et   *)
 (*  en Automatique.  All rights reserved.  This file is distributed    *)
-(*  under the terms of the Q Public License version 1.0.               *)
+(*  only by permission.                                                *)
 (*                                                                     *)
 (***********************************************************************)
 
@@ -16,6 +16,8 @@ Usage: compile with ocamlc, then execute the a.out program generated
        by ocamlc.
 
 ocamlc argcargv.ml
+
+Then try:
 a.out
 a.out 1 2
 a.out 1 2 "ok" -f "/tmp/foo"
